from enum import Enum


class BackgroundTaskType(str, Enum):
    ENDPOINT_REPLAY = "endpoint.replay"
    ENDPOINT_RECOVER = "endpoint.recover"
    APPLICATION_STATS = "application.stats"

    def __str__(self) -> str:
        return str(self.value)
